@@ -33,12 +33,14 @@
 #include <mptcpd/path_manager.h>
 #include <mptcpd/private/path_manager.h>
 #include <mptcpd/private/plugin.h>
+#include <mptcpd/private/network_monitor.h>
 #include <mptcpd/network_monitor.h>
 #include <mptcpd/private/id_manager.h>
 #include <mptcpd/id_manager.h>
 #include <mptcpd/private/sockaddr.h>
 #include <mptcpd/private/configuration.h>
 #include <mptcpd/private/addr_info.h>
+#include <mptcpd/private/listener_manager.h>
 
 // For netlink events.  Same API applies to multipath-tcp.org kernel.
 #include <mptcpd/private/mptcp_upstream.h>
@@ -117,16 +119,16 @@ struct pm_event_attrs
         /// Remote IPv6 address.
         struct in6_addr const *raddr6;
 
-        /// Local IP port  (network byte order).
+        /// Local TCP port  (network byte order).
         in_port_t const *local_port;
 
-        /// Remote IP port  (network byte order).
+        /// Remote TCP port  (network byte order).
         in_port_t const *remote_port;
 
         /// Network interface index.
         int32_t const *index;
 
-        /// MPTCP subflow backup priority status.
+        /// MPTCP subflow backup priority status (boolean).
         uint8_t const *backup;
 
         /**
@@ -136,6 +138,9 @@ struct pm_event_attrs
          *       @c struct @c sock in the Linux kernel.
          */
         uint8_t const *error;
+
+        /// Server side connection event (boolean)
+        uint8_t const *server_side;
 };
 
 /**
@@ -196,6 +201,9 @@ static void parse_netlink_attributes(struct l_genl_msg *msg,
                 case MPTCP_ATTR_IF_IDX:
                         MPTCP_GET_NL_ATTR(data, len, attrs->index);
                         break;
+                case MPTCP_ATTR_SERVER_SIDE:
+                        MPTCP_GET_NL_ATTR(data, len, attrs->server_side);
+                        break;
                 case MPTCP_ATTR_FAMILY:
                 case MPTCP_ATTR_FLAGS:
                 case MPTCP_ATTR_TIMEOUT:
@@ -220,7 +228,9 @@ static void handle_connection_created(struct pm_event_attrs const *attrs,
               Local port
               Remote address
               Remote port
-              Path management strategy (optional)
+
+              Upsteam kernel event attributes:
+                  Server side status
         */
         if (!attrs->token
             || !(attrs->laddr4 || attrs->laddr6)
@@ -249,11 +259,14 @@ static void handle_connection_created(struct pm_event_attrs const *attrs,
         }
 
         static char const *const pm_name = NULL;
+        bool const server_side =
+                (attrs->server_side != NULL ? *attrs->server_side : false);
 
         mptcpd_plugin_new_connection(pm_name,
                                      *attrs->token,
                                      (struct sockaddr *) &laddr,
                                      (struct sockaddr *) &raddr,
+                                     server_side,
                                      pm);
 }
 
@@ -267,6 +280,9 @@ static void handle_connection_established(struct pm_event_attrs const *attrs,
               Local port
               Remote address
               Remote port
+
+              Upsteam kernel event attributes:
+                  Server side status
         */
         if (!attrs->token
             || !(attrs->laddr4 || attrs->laddr6)
@@ -294,9 +310,14 @@ static void handle_connection_established(struct pm_event_attrs const *attrs,
                 return;
         }
 
+        // Assume server_side is false if event attribute is unavailable.
+        bool const server_side =
+                (attrs->server_side != NULL ? *attrs->server_side : false);
+
         mptcpd_plugin_connection_established(*attrs->token,
                                              (struct sockaddr *) &laddr,
                                              (struct sockaddr *) &raddr,
+                                             server_side,
                                              pm);
 }
 
@@ -888,6 +909,15 @@ struct mptcpd_pm *mptcpd_pm_create(struct mptcpd_config const *config)
                 return NULL;
         }
 
+        // Create mptcpd listener manager.
+        pm->lm = mptcpd_lm_create();
+
+        if (pm->lm == NULL) {
+                mptcpd_pm_destroy(pm);
+                l_error("Unable to create listener manager.");
+                return NULL;
+        }
+
         pm->event_ops = l_queue_new();
 
         return pm;
@@ -906,6 +936,7 @@ void mptcpd_pm_destroy(struct mptcpd_pm *pm)
         mptcpd_plugin_unload(pm);
 
         l_queue_destroy(pm->event_ops, l_free);
+        mptcpd_lm_destroy(pm->lm);
         mptcpd_idm_destroy(pm->idm);
         mptcpd_nm_destroy(pm->nm);
         l_timeout_remove(pm->timeout);
