@@ -4,7 +4,7 @@
  *
  * @brief MPTCP test plugin.
  *
- * Copyright (c) 2019-2021, Intel Corporation
+ * Copyright (c) 2019-2022, Intel Corporation
  */
 
 #pragma GCC diagnostic push
@@ -40,6 +40,7 @@ static struct sockaddr const *const remote_addr =
 static void plugin_two_new_connection(mptcpd_token_t token,
                                       struct sockaddr const *laddr,
                                       struct sockaddr const *raddr,
+                                      bool server_side,
                                       struct mptcpd_pm *pm)
 {
         (void) pm;
@@ -49,6 +50,7 @@ static void plugin_two_new_connection(mptcpd_token_t token,
         assert(!sockaddr_is_equal(laddr, raddr));
         assert(sockaddr_is_equal(laddr, local_addr));
         assert(sockaddr_is_equal(raddr, remote_addr));
+        assert(server_side == test_server_side_2);
 
         ++call_count.new_connection;
 }
@@ -57,6 +59,7 @@ static void plugin_two_connection_established(
         mptcpd_token_t token,
         struct sockaddr const *laddr,
         struct sockaddr const *raddr,
+        bool server_side,
         struct mptcpd_pm *pm)
 {
         (void) pm;
@@ -66,6 +69,7 @@ static void plugin_two_connection_established(
         assert(!sockaddr_is_equal(laddr, raddr));
         assert(sockaddr_is_equal(laddr, local_addr));
         assert(sockaddr_is_equal(raddr, remote_addr));
+        assert(server_side == test_server_side_2);
 
         ++call_count.connection_established;
 }
