@@ -4,7 +4,7 @@
  *
  * @brief MPTCP test plugin.
  *
- * Copyright (c) 2019-2021, Intel Corporation
+ * Copyright (c) 2019-2022, Intel Corporation
  */
 
 #pragma GCC diagnostic push
@@ -32,13 +32,15 @@ static struct plugin_call_count call_count;
 // ----------------------------------------------------------------
 
 static void plugin_four_new_connection(mptcpd_token_t token,
-                                        struct sockaddr const *laddr,
-                                        struct sockaddr const *raddr,
-                                        struct mptcpd_pm *pm)
+                                       struct sockaddr const *laddr,
+                                       struct sockaddr const *raddr,
+                                       bool server_side,
+                                       struct mptcpd_pm *pm)
 {
         (void) token;
         (void) laddr;
         (void) raddr;
+        (void) server_side;
         (void) pm;
 
         ++call_count.new_connection;
@@ -48,11 +50,13 @@ static void plugin_four_connection_established(
         mptcpd_token_t token,
         struct sockaddr const *laddr,
         struct sockaddr const *raddr,
+        bool server_side,
         struct mptcpd_pm *pm)
 {
         (void) token;
         (void) laddr;
         (void) raddr;
+        (void) server_side;
         (void) pm;
 
         ++call_count.connection_established;
