@@ -7,8 +7,14 @@
  * Copyright (c) 2021, 2022, Intel Corporation
  */
 
+#include <sys/un.h>
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpedantic"
 #include <ell/log.h>
 #include <ell/test.h>
+#include <ell/util.h>
+#pragma GCC diagnostic pop
 
 #include <mptcpd/private/sockaddr.h>
 
@@ -101,6 +107,73 @@ static void test_sockaddr_in6_init(void const *test_data)
                                     (struct sockaddr const *) &addr));
 }
 
+static void test_copy_null(void const *test_data)
+{
+        (void) test_data;
+
+        assert(mptcpd_sockaddr_copy(NULL) == NULL);
+}
+
+static bool test_copy_inet(struct sockaddr const *src)
+{
+        struct sockaddr *const dst = mptcpd_sockaddr_copy(src);
+
+        bool const is_equal = sockaddr_is_equal(src, dst);
+
+        l_free(dst);
+
+        return is_equal;
+}
+
+static void test_copy_af_inet(void const *test_data)
+{
+        (void) test_data;
+
+        struct sockaddr_in const addr = {
+                .sin_family = AF_INET,
+                .sin_port   = htons(0x1234),
+                .sin_addr   = {
+                        .s_addr = htonl(0xC0000201) // 192.0.2.1
+                }
+        };
+
+        struct sockaddr const *const src = (struct sockaddr const *) &addr;
+
+        assert(test_copy_inet(src));
+}
+
+static void test_copy_af_inet6(void const *test_data)
+{
+        (void) test_data;
+
+        struct sockaddr_in6 const addr = {
+                .sin6_family = AF_INET6,
+                .sin6_port   = htons(0x5678),
+                .sin6_addr   = {
+                        .s6_addr = { [0]  = 0x20,
+                                     [1]  = 0x01,
+                                     [2]  = 0x0D,
+                                     [3]  = 0xB8,
+                                     [14] = 0x01,
+                                     [15] = 0x02 }  // 2001:DB8::102
+                }
+        };
+
+        struct sockaddr const *const src =
+                (struct sockaddr const *) &addr;
+
+        assert(test_copy_inet(src));
+}
+
+static void test_copy_non_inet(void const *test_data)
+{
+        (void) test_data;
+
+        struct sockaddr const src = { .sa_family = AF_UNIX };
+
+        assert(mptcpd_sockaddr_copy(&src) == NULL);
+}
+
 int main(int argc, char *argv[])
 {
         l_log_set_stderr();
@@ -111,6 +184,10 @@ int main(int argc, char *argv[])
         l_test_add("bad sockaddr init", test_bad_sockaddr_init, NULL);
         l_test_add("sockaddr_in init",  test_sockaddr_in_init,  NULL);
         l_test_add("sockaddr_in6 init", test_sockaddr_in6_init, NULL);
+        l_test_add("copy - NULL",       test_copy_null,         NULL);
+        l_test_add("copy - AF_INET",    test_copy_af_inet,      NULL);
+        l_test_add("copy - AF_INET6",   test_copy_af_inet6,     NULL);
+        l_test_add("copy - non-INET",   test_copy_non_inet,     NULL);
 
         return l_test_run();
 }
